EZTV - TV Torrents Online
Description: EZTV, your one stop source for all your favorite TV shows.
Keywords: EZTV, EZ TV, EZTV Efnet, EZTV@EFnet, eztvefnet.org, eztv.it, Easy TV, Televison, 24, Prison Break, Lost, Stargate, Battlestar, Heroes, House, Dexter, Torrent, BitTorrent, Downloading,

Wednesday 17th of March 2010 06:55:20 EST

Airs today: Wednesday
South Park
Spicks & Specks
American Idol
Americas Next Top Model
Being Erica
Ugly Betty
Colbert Report, The
Daily Show, The
Mercy
Human Target (2010)
Craig Ferguson
Gary Unmarried
Law and Order: Special Victims Unit
MonsterQuest
New Adventures Of Old Christine, Th...
Website News
Website Stability
Issues with Vuze crashing? Read here
Welcome back!
RSS Feed for EZTV
New Forum on TV, Movies, Subtitles and more
EZTV on Twitter
For subtitles -> addic7ed.com
TV News
Scoop: 'Parks and Rec' collars Nata...
Lady GaGa to make guest cameo in 'G...
Clooney girlfriend to guest on 'Lev...
'True Blood' star defects to 'Good ...
Schneider quits 'Parks and Recreati...
Mary Steenburgen tapped as 'Souther...
'L Word' actress starring in USA's ...

Select Theme: [ Original ] • [ Light ] • [ Dark ]

Announcement
Do you want to help seed? We are always looking for new seeders who can sustain 10mbit and/or higher upload speeds! If you think you would be able to help seed at least five new torrents a day, likes the thought of receiving the shows before everyone else while giving back to the community, and have some free time - please stop by our IRC channel and contact an op. |
Username:
Password:
Login Register
Search: or Search

Featured Release
| Mixtape #1 "Home Taping Is Killing Music" - the BPI We're proud to be releasing this first VODO MIXTAPE. Actual tape might be a thing of the past, but before P2P, mixtapes were the most popular way of sharing popular culture the world had known -- and once called the 'most widely practiced American art form'. We want to resuscitate the spirit of the mixtape for this VODO MIXTAPE series: compilations of our favourite shorts, the weird, the wild and the wonky, all brought together in a temporary and uncomfortable company.
Download: | Donate to Artist: | Discuss: | Website:

| Display: 50 Releases | 100 Releases | next page >>

Television Show Releases
Info | Episode Name | Downloads | Released | Forum
Added on: 17, March, 2010
| BBC Jimmys Farm Series 1 3of4 November 2003 PDTV XviD AC3-MVGroup |  | 57m 3s |
| PBS Latin Music USA 1of4 Bridges x264 AC3-MVGroup |  | 2h 7m |
| American Idol S09E22 12 Finalists Compete HDTV XviD-FQM |  | 4h 34m |
| Parenthood 2010 S01E03 HDTV XviD-2HD |  | 5h |
| Justified S01E01 HDTV XviD-LOL |  | 5h 16m |
| The Colbert Report 2010 03 16 (HDTV-FQM) [VTV] |  | 5h 49m |
| David Letterman 2010 03 16 Jimmy Kimmel HDTV XviD-LMAO |  | 6h 1m |
| The Daily Show 2010 03 16 (HDTV-FQM) [VTV] |  | 6h 4m |
| Jay Leno 2010 03 16 Hugh Jackman HDTV XviD-LMAO |  | 6h 7m |
| FlashForward S01E00 Special What Did You See HDTV XviD-2HD |  | 6h 17m |
| Southland S02E03 U-Boat HDTV XviD-FQM |  | 6h 18m |
| Kids in the Hall Death Comes To Town S01E08 HDTV XviD-2HD |  | 6h 19m |
Added on: 16, March, 2010
| Law & Order SVU 11x16 (HDTV-2HD) [VTV] |  | 7h 46m |
| NCIS LA 1x18 (HDTV-2HD) [VTV] |  | 8h 24m |
| The Good Wife 1x17 (HDTV-LOL) [VTV] |  | 8h 25m |
| Lost S06E08 720p HDTV X264-DIMENSION |  | 8h 40m |
| Melrose Place 1x14 (HDTV-XII) [VTV] |  | 9h 23m |
| Craig Ferguson 2010 03 15 HDTV XviD-DVSKY |  | 10h |
| NCIS 7x18 (HDTV-LOL) [VTV] |  | 10h 24m |
| 90210 S02E14 HDTV XviD-LOL |  | 10h 31m |
| Lost S06E08 HDTV XviD-2HD |  | 11h 22m |
| BBC The Sky at Night 2010 03 Life PDTV XviD MP3-MVGroup |  | 14h 32m |
| BBC Seven Ages of Britain 1of7 Age of Conquest x264 AC3 HDTV-MVGroup |  | 16h 51m |
| CBC The Nature of Things Visions of the Future Vol 1 5of5 Earth Energy XviD AC3-MVGroup |  | 18h 2m |
| BBC Seven Ages of Britain 1of7 Age of Conquest XviD AC3-MVGroup |  | 19h 19m |
| Discovery Anthony Bourdain No Reservations Season 4 U S Southwest 2008 x264 720p AC3 HDTV-... |  | 1d 53s |
| BBC Jimmys Farm Series 1 2of4 August 2003 PDTV XviD AC3-MVGroup |  | 1d 5h |
| 24 S08E12 PROPER HDTV XviD-2HD |  | 1d 5h |
| Jay Leno 2010 03 15 Terry Bradshaw HDTV XviD-LMAO |  | 1d 6h |
| 24 S08E12 720p HDTV x264-IMMERSE |  | 1d 6h |
| Damages 3x08 (HDTV-LOL) [VTV] |  | 1d 6h |
Added on: 15, March, 2010
| The Colbert Report 2010 03 15 (HDTV-FQM) [VTV] |  | 1d 7h |
| The Daily Show 2010 03 15 (HDTV-FQM) [VTV] |  | 1d 7h |
| Little Mosque on the Prairie S04E18 HDTV XviD-2HD |  | 1d 7h |
| House S06E15 720p HDTV x264-IMMERSE |  | 1d 7h |
| Law and Order S20E16 HDTV XviD-LOL |  | 1d 7h |
| GREEK S03E18 Camp Buy Me Love HDTV XviD-FQM |  | 1d 7h |
| House S06E15 Black Hole PROPER HDTV XviD-FQM |  | 1d 8h |
| Gossip Girl 3x14 (HDTV-FQM) [VTV] |  | 1d 9h |
| Trauma S01E12 HDTV XviD-LOL |  | 1d 9h |
| 24 S08E12 HDTV XviD-CRiMSON |  | 1d 9h |
| Rules of Engagement 4x03 (HDTV-FQM) [VTV] |  | 1d 9h |
| House S06E15 READNFO HDTV XviD-CRiMSON |  | 1d 9h |
| The Secret Life of the American Teenager S02E23 I Got You Babe HDTV XviD-FQM |  | 1d 9h |
| Skins S04E07 HDTV XviD-BiA |  | 1d 9h |
| Life Unexpected S01E09 Formal Reformed HDTV XviD-FQM |  | 1d 10h |
| Chuck S03E10 HDTV XviD-LOL |  | 1d 10h |
| SyzygyNetwork InSight E40 HDTV x264-SYZYGY |  | 1d 13h |
| BBC Geisha Girl PDTV XviD MP3-MVGroup |  | 1d 14h |
| BBC The Sky at Night 2010 03 Life PDTV XviD MP3 MVGroup org |  | 1d 14h |

| Display: 50 Releases | 100 Releases | next page >>